@@ -1,6 +1,6 @@
 #! /usr/bin/perl -w
 
-# Copyright (c) 2003 Henk Penning, all rights reserved.
+# Copyright (c) 2003-2011 Henk Penning, all rights reserved.
 # penning@cs.uu.nl, http://www.cs.uu.nl/staff/henkp.html
 # Version 1.1 was donated to the Apache Software Foundation 2003 Jan 28.
 # Permission is hereby granted, free of charge, to any person obtaining a
@@ -28,7 +28,7 @@
 use strict ;
 
 our $PRG = 'mirmon' ;
-our $VER = "2.3" ;
+our $VER = "2.4" ;
 
 our $DEF_TIMEOUT = 300 ;
 our $HIST        = 14 ;
@@ -1429,7 +1429,7 @@ sub finish_probe
         if ( $res !~ /^\d+$/ )
           { $res =~ s/ /_/g ;
             $res = Base::htmlquote $res ;
-            $res = substr ( $time, 0, 15 ) . '..' if length $res > 15 ;
+            $res = substr ( $res, 0, 15 ) . '..' if length $res > 15 ;
             $stat = "'$res'" ;
           }
         else
@@ -1698,30 +1698,30 @@ mirmon(1)
 
 =begin html
 
-  &copy; 2003-2010
+  &copy; 2003-2011
   <A HREF="http://people.cs.uu.nl/henkp/">Henk P. Penning</A>,
   <A HREF="http://www.cs.uu.nl/">Computer Science Department</A>,
   <A HREF="http://www.uu.nl/">Utrecht University</A>
   <BR>
-  mirmon-2.3 - Wed Mar 17 09:29:11 2010 ; henkp
+  mirmon-2.4 - Mon Jan 17 18:14:46 2011 ; henkp
 
 =end html
 
 =begin man
 
-  (c) 2003-2010 Henk P. Penning
+  (c) 2003-2011 Henk P. Penning
   Computer Science Department, Utrecht University
   http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
-  mirmon-2.3 - Wed Mar 17 09:29:11 2010 ; henkp
+  mirmon-2.4 - Mon Jan 17 18:14:46 2011 ; henkp
 
 =end man
 
 =begin text
 
-  (c) 2003-2010 Henk P. Penning
+  (c) 2003-2011 Henk P. Penning
   Computer Science Department, Utrecht University
   http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
-  mirmon-2.3 - Wed Mar 17 09:29:11 2010 ; henkp
+  mirmon-2.4 - Mon Jan 17 18:14:46 2011 ; henkp
 
 =end text
 
